@@ -38,6 +38,10 @@ DEFAULTS = {
     "DEFAULT_PAGINATION_CLASS": None,
     #  Default permission classes
     "DEFAULT_PERMISSION_CLASSES": [],
+    # gRPC running mode
+    "GRPC_ASYNC": False,
+    #  Default grpc channel port
+    "GRPC_CHANNEL_PORT": 50051,
 }
 
 
