@@ -4,8 +4,9 @@ from django.test import TestCase
 from rest_framework.pagination import PageNumberPagination
 
 from django_socio_grpc import generics
+from fakeapp.models import UnitTestModel
+from fakeapp.serializers import UnitTestSerializer
 
-from .grpc_test_utils.django_classes_for_tests import UnitTestModel, UnitTestSerializer
 from .grpc_test_utils.fake_grpc import FakeGRPC
 from .grpc_test_utils.unittest_pb2 import UnitTestListRequest
 from .grpc_test_utils.unittest_pb2_grpc import (
@@ -26,8 +27,7 @@ class UnitTestService(generics.ModelService):
     pagination_class = StandardResultsSetPagination
 
 
-@UnitTestModel.fake_me
-class TestFiltering(TestCase):
+class TestPagination(TestCase):
     def setUp(self):
         for idx in range(10):
             title = "z" * (idx + 1)
@@ -45,9 +45,8 @@ class TestFiltering(TestCase):
         request = UnitTestListRequest()
         responses = grpc_stub.List(request=request)
 
-        responses_as_list = [response for response in responses]
-
-        self.assertEqual(len(responses_as_list), 3)
+        self.assertEqual(responses["count"], 10)
+        self.assertEqual(len(responses["results"]), 3)
 
     def test_another_page_number_pagination(self):
         grpc_stub = self.fake_grpc.get_fake_stub(UnitTestControllerStub)
@@ -56,6 +55,5 @@ class TestFiltering(TestCase):
         metadata = (("PAGINATION", (json.dumps(pagination_as_dict))),)
         responses = grpc_stub.List(request=request, metadata=metadata)
 
-        responses_as_list = [response for response in responses]
-
-        self.assertEqual(len(responses_as_list), 6)
+        self.assertEqual(responses["count"], 10)
+        self.assertEqual(len(responses["results"]), 6)
